Utilities for model operations
---
The goal is to avoid duplicate works

#####

Currently, this repo has the following utility applications:

1. Generate TT data points (go to ___create_tt_data___ for more details)
2. Train models by evolutionary algo (go to ___evol_training___ for more details)